@@ -1,12 +1,22 @@
-from .common import TOOAPI_Baseclass, TOOAPI_Daterange, TOOAPI_Instruments, TOOAPI_SkyCoord, TOOAPI_ObsID
+from .swift_clock import TOOAPI_ClockCorrect
+from .common import (
+    TOOAPI_Baseclass,
+    TOOAPI_Daterange,
+    TOOAPI_Instruments,
+    TOOAPI_SkyCoord,
+    TOOAPI_ObsID,
+    swiftdatetime
+)
 from .too_status import Swift_TOO_Status
 from .swift_obsquery import Swift_Observation, Swift_Observations
 from datetime import timedelta
 from .swift_resolve import TOOAPI_AutoResolve
 
 
-class Swift_PPST_Entry(TOOAPI_Baseclass, TOOAPI_SkyCoord, TOOAPI_ObsID, TOOAPI_Instruments):
-    '''Class that defines an individual entry in the Swift Pre-Planned Science
+class Swift_PPST_Entry(
+    TOOAPI_Baseclass, TOOAPI_SkyCoord, TOOAPI_ObsID, TOOAPI_Instruments
+):
+    """Class that defines an individual entry in the Swift Pre-Planned Science
     Timeline
 
     Attributes
@@ -37,13 +47,37 @@ class Swift_PPST_Entry(TOOAPI_Baseclass, TOOAPI_SkyCoord, TOOAPI_ObsID, TOOAPI_I
         SkyCoord version of RA/Dec if astropy is installed
     targname : str
         Target name of the primary target of the observation
-    '''
+    """
+
     # Core API defs
-    _parameters = ['begin', 'end', 'targname', 'ra', 'dec', 'roll',
-                   'targetid', 'seg', 'xrt', 'uvot', 'bat', 'fom']
-    names = ['Begin Time', 'End Time', 'Target Name',
-             'RA(J2000)', 'Dec(J200)', 'Roll (deg)', 'Target ID', 'Segment',
-             'XRT Mode', 'UVOT Mode', 'BAT Mode', 'Figure of Merit']
+    _parameters = [
+        "begin",
+        "end",
+        "targname",
+        "ra",
+        "dec",
+        "roll",
+        "targetid",
+        "seg",
+        "xrt",
+        "uvot",
+        "bat",
+        "fom",
+    ]
+    names = [
+        "Begin Time",
+        "End Time",
+        "Target Name",
+        "RA(J2000)",
+        "Dec(J200)",
+        "Roll (deg)",
+        "Target ID",
+        "Segment",
+        "XRT Mode",
+        "UVOT Mode",
+        "BAT Mode",
+        "Figure of Merit",
+    ]
     _attributes = []
     _subclasses = [Swift_TOO_Status]
     # API name
@@ -54,9 +88,9 @@ class Swift_PPST_Entry(TOOAPI_Baseclass, TOOAPI_SkyCoord, TOOAPI_ObsID, TOOAPI_I
         self.varnames = dict()
         for i in range(len(self._parameters)):
             self.varnames[self._parameters[i]] = self.names[i]
-        self.varnames['obsnum'] = 'Observation Number'
-        self.varnames['exposure'] = 'Exposure (s)'
-        self.varnames['slewtime'] = 'Slewtime (s)'
+        self.varnames["obsnum"] = "Observation Number"
+        self.varnames["exposure"] = "Exposure (s)"
+        self.varnames["slewtime"] = "Slewtime (s)"
 
         # Parameters
         self.begin = None
@@ -76,15 +110,34 @@ class Swift_PPST_Entry(TOOAPI_Baseclass, TOOAPI_SkyCoord, TOOAPI_ObsID, TOOAPI_I
     def exposure(self):
         return self.end - self.begin
 
+    def __header_title(self, parameter):
+        title = self.varnames[parameter]
+        value = getattr(self, parameter)
+        if type(value) == swiftdatetime:
+            if value.isutc:
+                title += " (UTC)"
+            else:
+                title += " (Swift)"
+        return title
+
     @property
     def _table(self):
-        _parameters = ['begin', 'end', 'targname', 'obsnum', 'exposure']
-        header = [self.varnames[row] for row in _parameters]
-        return header, [[self.begin, self.end, self.targname, self.obsnum, self.exposure.seconds]]
+        _parameters = ["begin", "end", "targname", "obsnum", "exposure"]
+        header = [self.__header_title(row) for row in _parameters]
+        return header, [
+            [self.begin, self.end, self.targname, self.obsnum, self.exposure.seconds]
+        ]
 
 
-class Swift_PPST(TOOAPI_Baseclass, TOOAPI_Daterange, TOOAPI_SkyCoord, TOOAPI_ObsID, TOOAPI_AutoResolve):
-    '''Class to fetch Swift Pre-Planned Science Timeline (PPST) for given
+class Swift_PPST(
+    TOOAPI_Baseclass,
+    TOOAPI_Daterange,
+    TOOAPI_SkyCoord,
+    TOOAPI_ObsID,
+    TOOAPI_AutoResolve,
+    TOOAPI_ClockCorrect,
+):
+    """Class to fetch Swift Pre-Planned Science Timeline (PPST) for given
     constraints. Essentially this will return what Swift was planned to observe
     and when, for given constraints. Constraints can be for give coordinate
     (SkyCoord or J2000 RA/Dec) and radius (in degrees), a given date range, or a
@@ -114,18 +167,26 @@ class Swift_PPST(TOOAPI_Baseclass, TOOAPI_Daterange, TOOAPI_SkyCoord, TOOAPI_Obs
         Status of API request
     ppstmax: datetime
         When is the PPST valid up to
-    '''
+    """
 
     # Core API definitions
-    _parameters = ['username', 'begin', 'end', 'ra',
-                   'dec', 'radius', 'targetid', 'obsnum']
-    _attributes = ['status', 'ppstmax', 'entries']
-    _local = ['obsid', 'name', 'skycoord', 'length', 'target_id']
+    _parameters = [
+        "username",
+        "begin",
+        "end",
+        "ra",
+        "dec",
+        "radius",
+        "targetid",
+        "obsnum",
+    ]
+    _attributes = ["status", "ppstmax", "entries"]
+    _local = ["obsid", "name", "skycoord", "length", "target_id", "shared_secret"]
     _subclasses = [Swift_PPST_Entry, Swift_TOO_Status]
     api_name = "Swift_PPST"
 
     def __init__(self, *args, **kwargs):
-        '''
+        """
         Parameters
         ----------
         begin : datetime
@@ -151,11 +212,11 @@ class Swift_PPST(TOOAPI_Baseclass, TOOAPI_Daterange, TOOAPI_SkyCoord, TOOAPI_Obs
             length of window
         shared_secret : str
             shared secret for TOO API (default 'anonymous')
-        '''
+        """
         # Coordinate search
         self.ra = None
         self.dec = None
-        self.radius = 11.8/60  # Default 11.8 arcmin - XRT FOV
+        self.radius = 11.8 / 60  # Default 11.8 arcmin - XRT FOV
         # begin and end boundaries
         self.begin = None
         self.end = None
@@ -164,7 +225,7 @@ class Swift_PPST(TOOAPI_Baseclass, TOOAPI_Daterange, TOOAPI_SkyCoord, TOOAPI_Obs
         self.targetid = None
         self.obsnum = None
         # Login
-        self.username = 'anonymous'
+        self.username = "anonymous"
         # PPST entries go here
         self.entries = list()
         # Status of request
@@ -207,17 +268,13 @@ class Swift_PPST(TOOAPI_Baseclass, TOOAPI_Daterange, TOOAPI_SkyCoord, TOOAPI_Obs
         return len(self.entries)
 
     def validate(self):
-        '''Make sure that all parameters required for a valid request are
-        passed'''
+        """Make sure that all parameters required for a valid request are
+        passed"""
         # How many search keys? Require at least one
         keys = self.api_data.keys()
 
         # We need at least one of these keys to be submitted
-        req_keys = ['begin',
-                    'ra',
-                    'dec',
-                    'targetid',
-                    'obsnum']
+        req_keys = ["begin", "ra", "dec", "targetid", "obsnum"]
 
         # Check how many of them are in the request
         total_keys = 0
@@ -228,12 +285,14 @@ class Swift_PPST(TOOAPI_Baseclass, TOOAPI_Daterange, TOOAPI_SkyCoord, TOOAPI_Obs
 
         # We need at least one key to be set
         if total_keys == 0:
-            self.status.error("ERROR: Please supply search parameters to narrow search.")
+            self.status.error(
+                "ERROR: Please supply search parameters to narrow search."
+            )
             return False
 
         # Check if ra or dec are in keys, we have both.
-        if 'ra' in keys or 'dec' in keys:
-            if not ('ra' in keys and 'dec' in keys):
+        if "ra" in keys or "dec" in keys:
+            if not ("ra" in keys and "dec" in keys):
                 self.status.error("ERROR: Must supply both RA and Dec.")
                 return False
 
